# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import cyberpy.interfaces.gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_link.proto',
  package='cyber.graph.v1beta1',
  syntax='proto3',
  serialized_options=b'Z/github.com/cybercongress/go-cyber/x/graph/types\310\341\036\000\250\342\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0emsg_link.proto\x12\x13\x63yber.graph.v1beta1\x1a\ngogo.proto\"s\n\x0cMsgCyberlink\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12>\n\x05links\x18\x02 \x03(\x0b\x32\x19.cyber.graph.v1beta1.LinkB\x14\xf2\xde\x1f\x0cyaml:\"links\"\xc8\xde\x1f\x00\"J\n\x04Link\x12\x1d\n\x04\x66rom\x18\x01 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"from\"\x12\x19\n\x02to\x18\x02 \x01(\tB\r\xf2\xde\x1f\tyaml:\"to\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x42\x39Z/github.com/cybercongress/go-cyber/x/graph/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogo__pb2.DESCRIPTOR,])




_MSGCYBERLINK = _descriptor.Descriptor(
  name='MsgCyberlink',
  full_name='cyber.graph.v1beta1.MsgCyberlink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cyber.graph.v1beta1.MsgCyberlink.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='links', full_name='cyber.graph.v1beta1.MsgCyberlink.links', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\014yaml:\"links\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=166,
)


_LINK = _descriptor.Descriptor(
  name='Link',
  full_name='cyber.graph.v1beta1.Link',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='cyber.graph.v1beta1.Link.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\013yaml:\"from\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='cyber.graph.v1beta1.Link.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\tyaml:\"to\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=242,
)

_MSGCYBERLINK.fields_by_name['links'].message_type = _LINK
DESCRIPTOR.message_types_by_name['MsgCyberlink'] = _MSGCYBERLINK
DESCRIPTOR.message_types_by_name['Link'] = _LINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgCyberlink = _reflection.GeneratedProtocolMessageType('MsgCyberlink', (_message.Message,), {
  'DESCRIPTOR' : _MSGCYBERLINK,
  '__module__' : 'msg_link_pb2'
  # @@protoc_insertion_point(class_scope:cyber.graph.v1beta1.MsgCyberlink)
  })
_sym_db.RegisterMessage(MsgCyberlink)

Link = _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
  'DESCRIPTOR' : _LINK,
  '__module__' : 'msg_link_pb2'
  # @@protoc_insertion_point(class_scope:cyber.graph.v1beta1.Link)
  })
_sym_db.RegisterMessage(Link)


DESCRIPTOR._options = None
_MSGCYBERLINK.fields_by_name['address']._options = None
_MSGCYBERLINK.fields_by_name['links']._options = None
_LINK.fields_by_name['from']._options = None
_LINK.fields_by_name['to']._options = None
_LINK._options = None
# @@protoc_insertion_point(module_scope)
